# Endpoints

```{eval-rst}

.. automodule:: torii_usb.usb.usb2.endpoints
	:members:

```

## Isochronous


```{eval-rst}

.. automodule:: torii_usb.usb.usb2.endpoints.isochronous
	:members:

```

## Status


```{eval-rst}

.. automodule:: torii_usb.usb.usb2.endpoints.status
	:members:

```

## Stream


```{eval-rst}

.. automodule:: torii_usb.usb.usb2.endpoints.stream
	:members:

```
